# gifmaker

![Brain](/docs/brain.gif)

Convert a series of images into a gif animation.

## Installation
~~~
pip install -e .
~~~

## Usage
~~~
gifmaker -i IMAGE1.png IMAGE2.png
gifmaker -i *.png
~~~

Note: all images mush have the same size.

For more features, run:
~~~
gifmaker -h
~~~
